from .constants import COLOR_MAPPING, RESET_CODE, CURSOR_UP, CLEAR

class ColorMeta(type):
    def __getattr__(cls, name):
        def apply_color(text):
            color_code = COLOR_MAPPING.get(name.lower(), "")
            return print(f'{color_code}{text}{RESET_CODE}')
        return apply_color

class crint(metaclass=ColorMeta):
    @staticmethod
    def unprint(lines=1):
        print((CURSOR_UP + CLEAR)*lines, end="")



# setup.py
from setuptools import setup, find_packages

setup(
    name='crint',
    version='0.1.0',
    description='A simple module for colored terminal output',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Raj Krishnan',
    author_email='rajkrishnan.r@outlook.com',
    url='https://github.com/raj-krishnan-r/crint',  # Replace with your GitHub repo URL
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=2.7',
)
